@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2023 -- leonerd@leonerd.org.uk
 
-package Object::Pad::FieldAttr::Checked 0.04;
+package Object::Pad::FieldAttr::Checked 0.05;
 
 use v5.14;
 use warnings;
@@ -76,9 +76,9 @@ more general, more powerful system being added in future.
    field $name :Checked(EXPRESSION) ...;
 
 Declares that any value assigned to the field during the constructor or using
-an accessor method must conform to the constraint checking object specified by
-the expression. Attempts to assign a non-conforming value will throw an
-exception and the field will not be modified. Currently only scalar fields are
+an accessor method must conform to the constraint checker specified by the
+expression. Attempts to assign a non-conforming value will throw an exception
+and the field will not be modified. Currently only scalar fields are
 supported.
 
 At compiletime, the string given by I<EXPRESSION> is C<eval()>'ed in scalar
@@ -95,14 +95,20 @@ names if required.
 
 At runtime, this constraint checker is used every time an attempt is made to
 assign a value to the field I<from outside the object class>, whether that is
-from C<:param> initialisation, or invoking a C<:writer> accessor. The checker
-is used as the invocant for invoking a C<check> method, and the new value for
-the field is passed as an argument. If the method returns true, the assignment
-is allowed. If false, it is rejected with an exception and the field itself
-remains unmodified.
+from C<:param> initialisation, or invoking a C<:writer> or C<:accessor>. The
+checker is used as the invocant for invoking a C<check> method, and the new
+value for  the field is passed as an argument. If the method returns true, the
+assignment is allowed. If false, it is rejected with an exception and the
+field itself remains unmodified.
 
    $ok = $checker->check( $value );
 
+(For performance reasons, the C<check> method is actually resolved into a
+function at compiletime when the C<:Checked> attribute is applied, and this
+stored function is the one that is called at assignment time. If the method
+itself is replaced later by globref assignment or other trickery, this updated
+function will not be used.)
+
 As this is the interface supported by L<Types::Standard>, any constraint
 object provided by that module is already supported here.
 
@@ -119,12 +125,6 @@ claim that even direct assignments would be checked. but this gave a false
 sense of safety if deeply-nested containers were involved and modified from
 within.
 
-(For performance reasons, the C<check> method is actually resolved into a
-function at compiletime when the C<:Checked> attribute is applied, and this
-stored function is the one that is called at assignment time. If the method
-itself is replaced later by globref assignment or other trickery, this updated
-function will not be used.)
-
 =cut
 
 sub import
@@ -143,7 +143,8 @@ sub unimport
 
 =item *
 
-Support C<:accessor> and C<:mutator> accessors as well as C<:writer>.
+Support C<:mutator> accessors as well. This is a bit harder because lvalue
+magic.
 
 =back
 
